package be.iminds.ilabt.jfed.util;

import org.testng.annotations.Test;

import static org.testng.Assert.*;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.*;

import static org.mockito.Mockito.mock;

public class IOUtilsTest {
    @Test
    public void testCurrentStackToStacktraceString() throws Exception {
        String curStackTrace = IOUtils.currentStackToStacktraceString();
        System.out.println("curStackTrace=\""+curStackTrace+"\"");
        assertThat(curStackTrace, is(notNullValue()));
        assertThat(curStackTrace, containsString("IOUtilsTest"));
        assertThat(curStackTrace, containsString("testCurrentStackToStacktraceString"));
    }

    @Test
    public void testExceptionToShortDescription() throws Exception {
        Throwable e;
        try {
            throw new RuntimeException();
        } catch (RuntimeException ex) {
            e = ex;
        }

        String shortDescription = IOUtils.exceptionToShortDescription(e);
        System.out.println("shortDescription=\""+shortDescription+"\"");
        assertThat(shortDescription, is(notNullValue()));
        assertThat(shortDescription, containsString("RuntimeException"));
        assertThat(shortDescription, containsString("in IOUtilsTest"));
        assertThat(shortDescription, containsString(".testExceptionToShortDescription("));
        assertThat(shortDescription, containsString(" @ line 26"));
    }

    @Test
    public void testSplitUnixPath() throws Exception {
        assertThat(IOUtils.splitUnixPath(".log").dir, is(equalTo("")));
        assertThat(IOUtils.splitUnixPath("/foo/.log").dir, is(equalTo("/foo/")));
        assertThat(IOUtils.splitUnixPath("/test.log").dir, is(equalTo("/")));
        assertThat(IOUtils.splitUnixPath("/foo/bar/baz/test.log").dir, is(equalTo("/foo/bar/baz/")));
        assertThat(IOUtils.splitUnixPath("~/test.log").dir, is(equalTo("~/")));
        assertThat(IOUtils.splitUnixPath("test.log").dir, is(equalTo("")));
        assertThat(IOUtils.splitUnixPath("//test.log").dir, is(equalTo("//")));
        assertThat(IOUtils.splitUnixPath("/test.log/noext").dir, is(equalTo("/test.log/")));
        assertThat(IOUtils.splitUnixPath("/test.log/ext.txt").dir, is(equalTo("/test.log/")));
        assertThat(IOUtils.splitUnixPath("baz/qux/test.log/ext.txt.foo.foobar").dir, is(equalTo("baz/qux/test.log/")));

        assertThat(IOUtils.splitUnixPath(".log").fileBase, is(equalTo(".log")));
        assertThat(IOUtils.splitUnixPath("/foo/.log").fileBase, is(equalTo(".log")));
        assertThat(IOUtils.splitUnixPath("/test.log").fileBase, is(equalTo("test")));
        assertThat(IOUtils.splitUnixPath("/foo/bar/baz/test.log").fileBase, is(equalTo("test")));
        assertThat(IOUtils.splitUnixPath("~/test.log").fileBase, is(equalTo("test")));
        assertThat(IOUtils.splitUnixPath("test.log").fileBase, is(equalTo("test")));
        assertThat(IOUtils.splitUnixPath("//test.log").fileBase, is(equalTo("test")));
        assertThat(IOUtils.splitUnixPath("/test.log/noext").fileBase, is(equalTo("noext")));
        assertThat(IOUtils.splitUnixPath("/test.log/ext.txt").fileBase, is(equalTo("ext")));
        assertThat(IOUtils.splitUnixPath("baz/qux/test.log/ext.txt.foo.foobar").fileBase, is(equalTo("ext.txt.foo")));

        assertThat(IOUtils.splitUnixPath(".log").ext, is(equalTo("")));
        assertThat(IOUtils.splitUnixPath("/foo/.log").ext, is(equalTo("")));
        assertThat(IOUtils.splitUnixPath("/test.log").ext, is(equalTo("log")));
        assertThat(IOUtils.splitUnixPath("/foo/bar/baz/test.log").ext, is(equalTo("log")));
        assertThat(IOUtils.splitUnixPath("~/test.log").ext, is(equalTo("log")));
        assertThat(IOUtils.splitUnixPath("test.log").ext, is(equalTo("log")));
        assertThat(IOUtils.splitUnixPath("//test.log").ext, is(equalTo("log")));
        assertThat(IOUtils.splitUnixPath("/test.log/noext").ext, is(equalTo("")));
        assertThat(IOUtils.splitUnixPath("/test.log/ext.txt").ext, is(equalTo("txt")));
        assertThat(IOUtils.splitUnixPath("baz/qux/test.log/ext.txt.foo.foobar").ext, is(equalTo("foobar")));

        assertThat(IOUtils.splitUnixPath(".log").getFullExt(), is(equalTo("")));
        assertThat(IOUtils.splitUnixPath("/foo/.log").getFullExt(), is(equalTo("")));
        assertThat(IOUtils.splitUnixPath("/test.log").getFullExt(), is(equalTo(".log")));
        assertThat(IOUtils.splitUnixPath("/foo/bar/baz/test.log").getFullExt(), is(equalTo(".log")));
        assertThat(IOUtils.splitUnixPath("~/test.log").getFullExt(), is(equalTo(".log")));
        assertThat(IOUtils.splitUnixPath("test.log").getFullExt(), is(equalTo(".log")));
        assertThat(IOUtils.splitUnixPath("//test.log").getFullExt(), is(equalTo(".log")));
        assertThat(IOUtils.splitUnixPath("/test.log/noext").getFullExt(), is(equalTo("")));
        assertThat(IOUtils.splitUnixPath("/test.log/ext.txt").getFullExt(), is(equalTo(".txt")));
        assertThat(IOUtils.splitUnixPath("baz/qux/test.log/ext.txt.foo.foobar").getFullExt(), is(equalTo(".foobar")));

        assertThat(IOUtils.splitUnixPath(".log").getFullPath(), is(equalTo(".log")));
        assertThat(IOUtils.splitUnixPath("/foo/.log").getFullPath(), is(equalTo("/foo/.log")));
        assertThat(IOUtils.splitUnixPath("/test.log").getFullPath(), is(equalTo("/test.log")));
        assertThat(IOUtils.splitUnixPath("/foo/bar/baz/test.log").getFullPath(), is(equalTo("/foo/bar/baz/test.log")));
        assertThat(IOUtils.splitUnixPath("~/test.log").getFullPath(), is(equalTo("~/test.log")));
        assertThat(IOUtils.splitUnixPath("test.log").getFullPath(), is(equalTo("test.log")));
        assertThat(IOUtils.splitUnixPath("//test.log").getFullPath(), is(equalTo("//test.log")));
        assertThat(IOUtils.splitUnixPath("/test.log/noext").getFullPath(), is(equalTo("/test.log/noext")));
        assertThat(IOUtils.splitUnixPath("/test.log/ext.txt").getFullPath(), is(equalTo("/test.log/ext.txt")));
        assertThat(IOUtils.splitUnixPath("baz/qux/test.log/ext.txt.foo.foobar").getFullPath(), is(equalTo("baz/qux/test.log/ext.txt.foo.foobar")));
    }
}